==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/df/d1c/structCursorVars.js <==
var structCursorVars =
[
    [ "UpdateCursorPosition", "df/d1c/structCursorVars.html#a18c8d9f350d78da59b93bb469b59a3da", null ],
    [ "animate_cur", "df/d1c/structCursorVars.html#a8d3d4cc9615eb04e965d4530c6397bc5", null ],
    [ "animate_list", "df/d1c/structCursorVars.html#a5cf1e24401a9809f655e3fd996b5bfc5", null ],
    [ "animate_timeout", "df/d1c/structCursorVars.html#a244e55a26cf7692aacea6737d16147bd", null ],
    [ "delta", "df/d1c/structCursorVars.html#af9166d0011c2afaa0e1f4051c1e822a6", null ],
    [ "dirty", "df/d1c/structCursorVars.html#a9bb10854f1520b9e3205cc35d2064ad3", null ],
    [ "draw_pos", "df/d1c/structCursorVars.html#a75e3bd89906b06fe6e53b8065faf427a", null ],
    [ "draw_size", "df/d1c/structCursorVars.html#aa82d2c175aa8b39e1f9299acbf8c94e4", null ],
    [ "fix_at", "df/d1c/structCursorVars.html#a52ef481e1ec9949a06640482c6b30481", null ],
    [ "h_wheel", "df/d1c/structCursorVars.html#a77a8f3edb42768062dd93d8382dce479", null ],
    [ "in_window", "df/d1c/structCursorVars.html#a7ee5ecf105d16b0cc2155bb4b41b4ab4", null ],
    [ "last_position", "df/d1c/structCursorVars.html#a463cb0349dcb30c50fe701b9f29a7c36", null ],
    [ "pos", "df/d1c/structCursorVars.html#a6f6b2ab19cfe004f9aaf3bc5ef9b0cf0", null ],
    [ "queued_warp", "df/d1c/structCursorVars.html#a7dbe8f8712450620f7bfa4c54e47c840", null ],
    [ "sprite_count", "df/d1c/structCursorVars.html#ae8cb68bfbaf8909ef65dfc3b8f702ec1", null ],
    [ "sprite_pos", "df/d1c/structCursorVars.html#a1b83600df0c018d84540374bf5ba1a71", null ],
    [ "sprite_seq", "df/d1c/structCursorVars.html#a9c02b0a7dcb7e56936f836e8bb950299", null ],
    [ "total_offs", "df/d1c/structCursorVars.html#a80572d4afff7919b7e06b35734e5d59f", null ],
    [ "total_size", "df/d1c/structCursorVars.html#a905b512b1fa82739092cd2bf4a192c1f", null ],
    [ "v_wheel", "df/d1c/structCursorVars.html#a56181dbb5aefdd084a98ea423b1693cd", null ],
    [ "vehchain", "df/d1c/structCursorVars.html#a7c729e657e51467fda1291234e2952c5", null ],
    [ "visible", "df/d1c/structCursorVars.html#a01d870028d786058d515c1d2e6de34c8", null ],
    [ "wheel", "df/d1c/structCursorVars.html#a89e58039a7cd4d816de7d06755c18068", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/df/d1c/structCursorVars.js <==
var structCursorVars =
[
    [ "UpdateCursorPosition", "df/d1c/structCursorVars.html#a18c8d9f350d78da59b93bb469b59a3da", null ],
    [ "UpdateCursorPositionRelative", "df/d1c/structCursorVars.html#a710a5146f57c15a07cbe2c24b4f49429", null ],
    [ "animate_cur", "df/d1c/structCursorVars.html#a8d3d4cc9615eb04e965d4530c6397bc5", null ],
    [ "animate_list", "df/d1c/structCursorVars.html#a5cf1e24401a9809f655e3fd996b5bfc5", null ],
    [ "animate_timeout", "df/d1c/structCursorVars.html#a244e55a26cf7692aacea6737d16147bd", null ],
    [ "delta", "df/d1c/structCursorVars.html#af9166d0011c2afaa0e1f4051c1e822a6", null ],
    [ "dirty", "df/d1c/structCursorVars.html#a9bb10854f1520b9e3205cc35d2064ad3", null ],
    [ "draw_pos", "df/d1c/structCursorVars.html#a75e3bd89906b06fe6e53b8065faf427a", null ],
    [ "draw_size", "df/d1c/structCursorVars.html#aa82d2c175aa8b39e1f9299acbf8c94e4", null ],
    [ "fix_at", "df/d1c/structCursorVars.html#a52ef481e1ec9949a06640482c6b30481", null ],
    [ "h_wheel", "df/d1c/structCursorVars.html#a77a8f3edb42768062dd93d8382dce479", null ],
    [ "in_window", "df/d1c/structCursorVars.html#a7ee5ecf105d16b0cc2155bb4b41b4ab4", null ],
    [ "last_position", "df/d1c/structCursorVars.html#a463cb0349dcb30c50fe701b9f29a7c36", null ],
    [ "pos", "df/d1c/structCursorVars.html#a6f6b2ab19cfe004f9aaf3bc5ef9b0cf0", null ],
    [ "queued_warp", "df/d1c/structCursorVars.html#a7dbe8f8712450620f7bfa4c54e47c840", null ],
    [ "sprite_count", "df/d1c/structCursorVars.html#ae8cb68bfbaf8909ef65dfc3b8f702ec1", null ],
    [ "sprite_pos", "df/d1c/structCursorVars.html#a1b83600df0c018d84540374bf5ba1a71", null ],
    [ "sprite_seq", "df/d1c/structCursorVars.html#a9c02b0a7dcb7e56936f836e8bb950299", null ],
    [ "total_offs", "df/d1c/structCursorVars.html#a80572d4afff7919b7e06b35734e5d59f", null ],
    [ "total_size", "df/d1c/structCursorVars.html#a905b512b1fa82739092cd2bf4a192c1f", null ],
    [ "v_wheel", "df/d1c/structCursorVars.html#a56181dbb5aefdd084a98ea423b1693cd", null ],
    [ "vehchain", "df/d1c/structCursorVars.html#a7c729e657e51467fda1291234e2952c5", null ],
    [ "visible", "df/d1c/structCursorVars.html#a01d870028d786058d515c1d2e6de34c8", null ],
    [ "wheel", "df/d1c/structCursorVars.html#a89e58039a7cd4d816de7d06755c18068", null ]
];
